@@ -115,12 +115,13 @@ typedef unsigned long guintptr;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 84
-#define GLIB_MICRO_VERSION 3
+#define GLIB_MICRO_VERSION 4
 
 #define G_OS_UNIX
 
 #define G_VA_COPY va_copy
 
+#define G_VA_COPY_AS_ARRAY 1
 
 #define G_HAVE_ISO_VARARGS 1
 
@@ -213,7 +214,7 @@ typedef int GPid;
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
-#undef G_HAVE_FREE_SIZED
+#define G_HAVE_FREE_SIZED
 
 G_END_DECLS
 
